==> geant4.10.01.p01.tar.gz: geant4.10.01.p01/examples/.doxygen/Doxymodules_medical.h <==
// $Id: Doxymodules_medical.h 86514 2014-11-13 09:10:24Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_medical.h
/// \brief The page that defines the extended/medical examples modules 


/** @defgroup extended_medical medical
 *  Extended medical examples classes
 *  @{
 */

/** @defgroup extended_medical_DICOM DICOM
 *  Medical example DICOM 
 *  @ingroup extended_medical
 *  @{
 */

  class DicomActionInitialization {};
  class DicomDetectorConstruction {};
  class DicomEventAction {};
  class DicomHandler {};
  class DicomIntersectVolume {};
  class DicomNestedParamDetectorConstruction {};
  class DicomNestedPhantomParameterisation {};
  class DicomPartialDetectorConstruction {};
  class DicomPhantomParameterisationColour {};
  class DicomPhantomZSliceHeader {};
  class DicomPhantomZSliceMerged {};
  class DicomPrimaryGeneratorAction {};
  class DicomRegularDetectorConstruction {};
  class DicomRunAction {};
  class DicomRun {};

/** @} */

/** @defgroup extended_medical_electronScattering electronScattering
 *  Medical electronScattering example has its
 *  <a href="../html_electronScattering/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_electronScattering2 electronScattering2
 *  Medical electronScattering2 example has its
 *  <a href="../html_electronScattering2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity fanoCavity
 *  Medical fanoCavity example has its
 *  <a href="../html_fanoCavity/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity2 fanoCavity2
 *  Medical fanoCavity2 example has its
 *  <a href="../html_fanoCavity2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_GammaTherapy GammaTherapy
 *  Medical GammaTherapy example has its
 *  <a href="../html_GammaTherapy/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna dna
 *  Extended examples medical dna classes
 *  @{
 */

/** @defgroup extended_medical_dna_chem1 chem1
 *  Medical dna chem1 example has its
 *  <a href="../html_chem1/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_chem2 chem2
 *  Medical dna chem1 example has its
 *  <a href="../html_chem2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_chem3 chem3
 *  Medical dna chem1 example has its
 *  <a href="../html_chem3/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_dnaphysics dnaphysics
 *  Medical dna dnaphysics example has its
 *  <a href="../html_dnaphysics/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_microdosimetry microdosimetry
 *  Medical dna microdosimetry example has its
 *  <a href="../html_microdosimetry/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_pdb4dna pdb4dna
 *  Medical dna pdb4dna example has its
 *  <a href="../html_pdb4dna/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_wholeNuclearDNA wholeNuclearDNA
 *  Medical dna wholeNuclearDNA example has its
 *  <a href="../html_wholeNuclearDNA/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @} */

/** @} */

==> geant4.10.02.p02.tar.gz: geant4.10.02.p02/examples/.doxygen/Doxymodules_medical.h <==
// $Id: Doxymodules_medical.h 94561 2015-11-24 09:17:12Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_medical.h
/// \brief The page that defines the extended/medical examples modules 


/** @defgroup extended_medical medical
 *  Extended medical examples classes
 *  @{
 */

/** @defgroup extended_medical_DICOM DICOM
 *  Medical example DICOM 
 *  @ingroup extended_medical
 *  @{
 */

  class DicomActionInitialization {};
  class DicomDetectorConstruction {};
  class DicomEventAction {};
  class DicomHandler {};
  class DicomIntersectVolume {};
  class DicomNestedParamDetectorConstruction {};
  class DicomNestedPhantomParameterisation {};
  class DicomPartialDetectorConstruction {};
  class DicomPhantomParameterisationColour {};
  class DicomPhantomZSliceHeader {};
  class DicomPhantomZSliceMerged {};
  class DicomPrimaryGeneratorAction {};
  class DicomRegularDetectorConstruction {};
  class DicomRunAction {};
  class DicomRun {};

/** @} */

/** @defgroup extended_medical_electronScattering electronScattering
 *  Medical electronScattering example has its
 *  <a href="../html_electronScattering/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_electronScattering2 electronScattering2
 *  Medical electronScattering2 example has its
 *  <a href="../html_electronScattering2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity fanoCavity
 *  Medical fanoCavity example has its
 *  <a href="../html_fanoCavity/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity2 fanoCavity2
 *  Medical fanoCavity2 example has its
 *  <a href="../html_fanoCavity2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_GammaTherapy GammaTherapy
 *  Medical GammaTherapy example has its
 *  <a href="../html_GammaTherapy/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna dna
 *  Extended examples medical dna classes
 *  @{
 */

/** @defgroup extended_medical_dna_chem1 chem1
 *  Medical dna chem1 example has its
 *  <a href="../html_chem1/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_chem2 chem2
 *  Medical dna chem1 example has its
 *  <a href="../html_chem2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_chem3 chem3
 *  Medical dna chem1 example has its
 *  <a href="../html_chem3/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_dnaphysics dnaphysics
 *  Medical dna dnaphysics example has its
 *  <a href="../html_dnaphysics/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_microdosimetry microdosimetry
 *  Medical dna microdosimetry example has its
 *  <a href="../html_microdosimetry/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_microyz microyz
 *  Medical dna microyz example has its
 *  <a href="../html_microyz/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_pdb4dna pdb4dna
 *  Medical dna pdb4dna example has its
 *  <a href="../html_pdb4dna/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_svalue svalue
 *  Medical dna svalue example has its
 *  <a href="../html_svalue/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_wholeNuclearDNA wholeNuclearDNA
 *  Medical dna wholeNuclearDNA example has its
 *  <a href="../html_wholeNuclearDNA/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @defgroup extended_medical_dna_wvalue wvalue
 *  Medical dna wvalue example has its
 *  <a href="../html_wvalue/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical_dna
 *  @{
 */

/** @} */

/** @} */

/** @} */
